LLMHosts Dashboard

Savings Overview
$0.00
saved vs cloud-only pricing
0% saved
Total Requests 0
Local 0
Cloud 0
Cache Hits 0
Actual Cost $0.00
Cloud Equivalent $0.00
Requests / min
0 rpm
0 total
Cache Hit Rate
0%
semantic + exact match
Avg Latency
0 ms
across all backends
Savings
$0
total saved
Backend Split
Local: 0 Cloud: 0 Cache: 0
0 active models
Request Log 0 requests

Time | Requested | Used | Backend | Cost | Saved | Latency
--- | --- | --- | --- | --- | --- | ---

No requests yet
Send a request to your LLMHosts proxy to see it here
Backends 0 backends
No backends detected
Start Ollama or configure cloud API keys